|
From: <the...@us...> - 2022-11-21 00:21:15
|
Revision: 1289
http://sourceforge.net/p/seq/svn/1289
Author: theblueadept
Date: 2022-11-21 00:21:13 +0000 (Mon, 21 Nov 2022)
Log Message:
-----------
Historical checkin for 11/20/22
- Fix for LDON objects (Newby)
Version to 6.2.13
Modified Paths:
--------------
showeq/trunk/ChangeLog
showeq/trunk/configure.in
showeq/trunk/src/spawnshell.cpp
Modified: showeq/trunk/ChangeLog
===================================================================
--- showeq/trunk/ChangeLog 2022-11-20 22:00:32 UTC (rev 1288)
+++ showeq/trunk/ChangeLog 2022-11-21 00:21:13 UTC (rev 1289)
@@ -1,3 +1,8 @@
+BlueAdept (11/20/22)
+----------------
+- Update to version 6.2.13
+- Fix for LDON objects (Newby)
+
BlueAdept (11/17/22)
----------------
- Update to version 6.2.12
Modified: showeq/trunk/configure.in
===================================================================
--- showeq/trunk/configure.in 2022-11-20 22:00:32 UTC (rev 1288)
+++ showeq/trunk/configure.in 2022-11-21 00:21:13 UTC (rev 1289)
@@ -2,7 +2,7 @@
dnl $Id$ $Name$
AC_PREREQ(2.59)
-AC_INIT(showeq, 6.2.12)
+AC_INIT(showeq, 6.2.13)
AC_CONFIG_SRCDIR(src/main.cpp)
AC_CONFIG_MACRO_DIR([m4])
AC_CANONICAL_SYSTEM
Modified: showeq/trunk/src/spawnshell.cpp
===================================================================
--- showeq/trunk/src/spawnshell.cpp 2022-11-20 22:00:32 UTC (rev 1288)
+++ showeq/trunk/src/spawnshell.cpp 2022-11-21 00:21:13 UTC (rev 1289)
@@ -689,7 +689,7 @@
netStream.readText(); // skip 3 variable len strings
netStream.readText();
netStream.readText();
- netStream.skipBytes(58); // and 58 static bytes
+ netStream.skipBytes(54); // and 54 static bytes
}
spawn->charProperties = netStream.readUInt8();
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|